pub struct FixResult {
pub files_modified: usize,
pub edits_applied: usize,
pub edits_skipped: usize,
pub edits_subsumed: usize,
pub errors: Vec<String>,
pub modified_files: Vec<PathBuf>,
}Expand description
Result of applying a fix plan.
Fields
files_modified: usizeNumber of files modified.
edits_applied: usizeNumber of edits applied.
edits_skipped: usizeNumber of edits skipped (line out of bounds or text not found).
edits_subsumed: usizeNumber of edits subsumed by a more specific edit on the same line.
errors: Vec<String>Errors encountered.
modified_files: Vec<PathBuf>Paths of files that were actually modified on disk.